async fn handle_native_pick_folder(
app_handle: AppHandle,
_args: Vec<Value>,
) -> Result<Value, String>Expand description
Pick folder using Tauri dialog plugin and reload webview with folder param.
In Electron, pickFolderAndOpen causes the main process to reload the window
with the new workspace. We replicate this by navigating the webview to the
same origin with ?folder=<path>, which ResolveConfiguration reads.